/*
 * Project name:
     DIGI POT 2 click
 * Copyright:
     (c) Mikroelektronika, 2016.
  * Revision History
     20160622 (AM);
       - initial release;
 * Description:
     This program demonstrates the usage of Digital Potentiometer 2 Board (TPL0501).
     Voltage derived from W pin is read by MCU's ADC (AN0). Scaled value is then displayed at TFT.
     User can increase or decrease resitance by pressing buttons RD0 and RD1. It's all happening in an endless loop.
 * Test configuration:
     Device:          STM32F107VC
                      http://www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/DATASHEET/CD00220364.pdf
     Dev.Board:       EasyMx v7 for STM32
                      http://www.mikroe.com/eng/products/view/852/easymx-pro-v7-for-stm32/
     Oscillator:      72.0000 MHz HS+PLL
     ext. module      Digi Pot 2 click

     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/mikroc/arm/
 * NOTES:
     - Digi Pot 2 click must be connected on mikroBUS socket 1.
     - Connect DigiPot's H to Vcc, L to Gnd and W to RA0 pin.
     - Don't use pull-up(down) resistor at RA0 pin.
     - Place Button Press Level switch in upper position for PORTD
           and pull down PortD pins 0 and 1 (PortD three-state switch).
     - Turn ON TFT backlight (SW11.3)
*/
#include "built_in.h"
#include "resources.h"

sbit DigPot_CS at GPIOD_ODR.B13;

unsigned int adc_value;
unsigned short counter;

/**************************************************************************************************
* Draw Screen
**************************************************************************************************/
void DrawScr(){
  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_Black, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_LIne(20,  46, 300,  46);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("DigiPot 2 click  TEST", 75, 14);
  TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyMX PRO v7", 19, 223);
  TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("www.mikroe.com", 200, 223);
  TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
}

/**************************************************************************************************
* Main Init
**************************************************************************************************/
void InitMain() {

  GPIO_Digital_Output(&GPIOD_BASE, _GPIO_PINMASK_13);
  GPIO_Digital_Input(&GPIOD_BASE, _GPIO_PINMASK_0 | _GPIO_PINMASK_1);

  ADC1_Init();
  ADC_Set_Input_Channel(_ADC_CHANNEL_0);

  DigPot_CS = 1;

  // Initialize SPI1 module
  SPI3_Init_Advanced(_SPI_FPCLK_DIV128, _SPI_MASTER  | _SPI_8_BIT |
                     _SPI_CLK_IDLE_LOW | _SPI_FIRST_CLK_EDGE_TRANSITION |
                     _SPI_MSB_FIRST | _SPI_SS_DISABLE | _SPI_SSM_ENABLE | _SPI_SSI_1,
                     &_GPIO_MODULE_SPI3_PC10_11_12);

  adc_value = 0;
  counter = 200;

  TFT_Init_ILI9341_8bit(320, 240);
}

/**************************************************************************************************
* Write Graph
**************************************************************************************************/
void Wr_Graph(int value){
static int oldvalue = 0;

  if (value < oldvalue){
    TFT_Set_Pen(CL_WHITE, 1);
    TFT_Set_Brush(1, CL_WHITE, 0, 0, 0, 0);
    TFT_Rectangle(150, 200 - oldvalue/35, 170, 200 - value/35);
  }
  else{
    TFT_Set_Pen(CL_RED, 1);
    TFT_Set_Brush(1, CL_RED, 0, 0, 0, 0);
    TFT_Rectangle(150, 200 - value/35, 170, 200 - oldvalue/35);
  }
  oldvalue = value;
}

/**************************************************************************************************
* Main Function
**************************************************************************************************/
void main() {

  InitMain();                            // Perform main initialization
  Delay_ms(100);

  DrawScr();
  TFT_Write_Text("Press buttons PD0 and PD1 to change output", 20, 50);
  TFT_Set_Pen(CL_RED, 1);

  while (1) {                            // Endless loop

    DigPot_CS = 0;                       // Select PotentioMeter chip
    SPI3_Write(0);
    SPI3_Write(counter);

    SPI3_Write(0x20);
    SPI3_Write(counter);
    DigPot_CS = 1;                       // Deselect PotentioMeter chip

    adc_value = ADC1_Get_Sample(0);      // Get 10-bit results of AD conversion

    Wr_Graph(adc_value);

    if (GPIOD_IDR.B1) {                  // Press RD1 to decrease resistance between W and L
      counter ++;
      if (counter == 255)
        counter = 127;
    }
    if (GPIOD_IDR.B0) {                  // Press RD0 to increase resistance between W and L
      counter --;
      if (counter == 127)
        counter = 255;
    }
    Delay_ms(50);                        // Delay for debouncing
  }
}

/**************************************************************************************************
* End of File
**************************************************************************************************/