/*
 * Project name:
     DIGI POT 2 click
 * Copyright:
     (c) Mikroelektronika, 2016.
  * Revision History
     20160622 (AM);
       - initial release;
 * Description:
     This program demonstrates the usage of Digital Potentiometer 2 Board (TPL0501).
     Voltage derived from W pin is read by MCU's ADC (AN0). Scaled value is then displayed at TFT.
     User can increase or decrease resitance by pressing buttons RD0 and RD1. It's all happening in an endless loop.
 * Test configuration:
     MCU:             LM3S9B95
                      http://www.ti.com/lit/ds/symlink/lm3s9b95.pdf
     Dev. Board:      EasyMx v7 for STELLARIS(R) ARM(R)
                      http://www.mikroe.com/easymx-pro/stellaris/
     Oscillator:      XT-PLL, 80.000MHz
     Ext. modules:    Digi Pot 2 click
     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/mikroc/arm/
 * NOTES:
     - Digi Pot 2 Board must be connected on mikroBUS socket 1.
     - Turn on TFT control switches on SW11 and SW12. (board specific)
     - Connect DigiPot's H to Vcc, L to Gnd and W to RD7 pin.
     - Don't use pull-up(down) resistor at RD7 pin.
     - Place Button Press Level switch in upper position for PORTG
           and pull down PortG pins 5 and 6 (PortG three-state switch).
     - Turn ON TFT backlight (SW11.3)
*/

#include "resources.h"

sbit DigPot_CS at GPIO_PORTG_DATA.B0;

unsigned int adc_value;
unsigned short counter;

/**************************************************************************************************
* Draw Screen
**************************************************************************************************/
void DrawScr(){
  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_BLACK, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_Line(20,  46, 300,  46);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("DigiPot 2 click  TEST", 75, 14);
  TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyMX PRO v7 for Stellaris", 19, 223);
  TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("www.mikroe.com", 200, 223);
  TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
}

/**************************************************************************************************
* Main Init
**************************************************************************************************/
void InitMain() {
  // Set BLED as output
  GPIO_Digital_Output(&GPIO_PORTA, _GPIO_PINMASK_3);
  TFT_BLED = 1;

  // Set Chip Select pin as Output
  GPIO_Config(&GPIO_PORTG_DATA, _GPIO_PINMASK_0, _GPIO_DIR_OUTPUT, _GPIO_CFG_DIGITAL_ENABLE, 0);

  // Set PD0 and PD1 as digital input
  GPIO_Digital_Input(&GPIO_PORTD, _GPIO_PINMASK_0 | _GPIO_PINMASK_1);

  ADC1_Init();
  ADC_Set_Input_Channel(_ADC_CHANNEL_0);

  DigPot_CS = 1;

  // SPI config
  SPI0_Init_Advanced(1000000, _SPI_MASTER, _SPI_8_BIT, &_GPIO_MODULE_SPI0_A245);

  adc_value = 0;
  counter = 200;

  TFT_Init_ILI9341_8bit(320, 240);
}

/**************************************************************************************************
* Write Graph
**************************************************************************************************/
void Wr_Graph(int value){
static int oldvalue = 0;

  if (value < oldvalue){
    TFT_Set_Pen(CL_WHITE, 1);
    TFT_Set_Brush(1, CL_WHITE, 0, 0, 0, 0);
    TFT_Rectangle(150, 200 - oldvalue/9, 170, 200 - value/9);
  }
  else{
    TFT_Set_Pen(CL_RED, 1);
    TFT_Set_Brush(1, CL_RED, 0, 0, 0, 0);
    TFT_Rectangle(150, 200 - value/9, 170, 200 - oldvalue/9);
  }
  oldvalue = value;
}

/**************************************************************************************************
* Main Function
**************************************************************************************************/
void main() {

  InitMain();                            // Perform main initialization
  Delay_ms(100);

  DrawScr();
  TFT_Write_Text("Press buttons PD0 and PD1 to change output", 20, 50);
  TFT_Set_Pen(CL_RED, 1);

  while (1) {                            // Endless loop

    DigPot_CS = 0;                       // Select PotentioMeter chip
    SPI0_Write(0);
    SPI0_Write(counter);

    SPI0_Write(0x20);
    SPI0_Write(counter);
    DigPot_CS = 1;                       // Deselect PotentioMeter chip

    adc_value = ADC1_Get_Sample(0);      // Get 10-bit results of AD conversion

    Wr_Graph(adc_value);

    if (Button(&GPIO_PORTD_DATA, 1, 10, 1)) {                  // Press RD1 to decrease resistance between W and L
      counter ++;
      if (counter == 255)
        counter = 0;
    }
    if (Button(&GPIO_PORTD_DATA, 0, 10, 1)) {                  // Press RD0 to increase resistance between W and L
      counter --;
      if (counter == 0)
        counter = 255;
    }
    Delay_ms(50);                        // Delay for debouncing
  }
}